@@ -3,8 +3,9 @@ Main interface for elb service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elb import (
+    from mypy_boto3_elb import (
         AnyInstanceInServiceWaiter,
         Client,
         DescribeAccountLimitsPaginator,
@@ -12,7 +13,7 @@ Usage::
         ElasticLoadBalancingClient,
         InstanceDeregisteredWaiter,
         InstanceInServiceWaiter,
-        )
+    )
 
     session = boto3.Session()
 
@@ -25,8 +26,9 @@ Usage::
 
     describe_account_limits_paginator: DescribeAccountLimitsPaginator = client.get_paginator("describe_account_limits")
     describe_load_balancers_paginator: DescribeLoadBalancersPaginator = client.get_paginator("describe_load_balancers")
+    ```
 """
-from mypy_boto3_elb.client import ElasticLoadBalancingClient, ElasticLoadBalancingClient as Client
+from mypy_boto3_elb.client import ElasticLoadBalancingClient as Client, ElasticLoadBalancingClient
 from mypy_boto3_elb.paginator import DescribeAccountLimitsPaginator, DescribeLoadBalancersPaginator
 from mypy_boto3_elb.waiter import (
     AnyInstanceInServiceWaiter,
