@@ -3,13 +3,15 @@ Main interface for elb service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elb import ElasticLoadBalancingClient
+    from mypy_boto3_elb import ElasticLoadBalancingClient
 
     session = boto3.Session()
 
     client: ElasticLoadBalancingClient = boto3.client("elb")
     session_client: ElasticLoadBalancingClient = session.client("elb")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
