@@ -3,8 +3,11 @@ Main interface for elb service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elb import (
+
+    from mypy_boto3_elb import ElasticLoadBalancingClient
+    from mypy_boto3_elb import (
         DescribeAccountLimitsPaginator,
         DescribeLoadBalancersPaginator,
     )
@@ -13,6 +16,7 @@ Usage::
 
     describe_account_limits_paginator: DescribeAccountLimitsPaginator = client.get_paginator("describe_account_limits")
     describe_load_balancers_paginator: DescribeLoadBalancersPaginator = client.get_paginator("describe_load_balancers")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, List, TYPE_CHECKING
