@@ -3,8 +3,11 @@ Main interface for elb service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.elb import (
+
+    from mypy_boto3_elb import ElasticLoadBalancingClient
+    from mypy_boto3_elb import (
         AnyInstanceInServiceWaiter,
         InstanceDeregisteredWaiter,
         InstanceInServiceWaiter,
@@ -15,6 +18,7 @@ Usage::
     any_instance_in_service_waiter: AnyInstanceInServiceWaiter = client.get_waiter("any_instance_in_service")
     instance_deregistered_waiter: InstanceDeregisteredWaiter = client.get_waiter("instance_deregistered")
     instance_in_service_waiter: InstanceInServiceWaiter = client.get_waiter("instance_in_service")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import List, TYPE_CHECKING
